@@ -54,16 +54,6 @@ def add_crud_handler(config, route_name_prefix='', url_pattern_prefix='', handle
                        handler=handler_class)
 
 
-def _get_field_args(model, action_type):
-    field_args = self.add_edit_field_args
-
-    cols = get_columns(self.model, 'foreign_key')
-    for c in cols:
-        pass
-
-    return field_args
-
-
 class CRUDController(object):
     """
     Enables automatic CRUD interface generation from database models. The :class:`pyck.controllers.CRUDController`
@@ -73,11 +63,11 @@ class CRUDController(object):
     1. Create a sub-class of the CRUDController and set model (for which you want to have CRUD) and database session::
 
         from pyck.controllers import CRUDController
-        from myapp.models import MyModel, DBSession
+        from myapp.models import MyModel, db
 
         class MyCRUDController(CRUDController):
             model = MyModel
-            db_session = DBSession()
+            db_session = db
 
     2. In your application's routes settings, specify the url where the CRUD interface should be displayed. You can use
        the :func:`pyck.controllers.add_crud_handler` method for it. For example in your __init__.py (if you're enabling
@@ -215,7 +205,8 @@ class CRUDController(object):
             pass
         else:
             pk_name = primary_key_columns[0]
-            R = self.db_session.query(self.model).filter("%s=%s" % (pk_name, pk_val)).one()
+            #R = self.db_session.query(self.model).filter("%s=%s" % (pk_name, pk_val)).one()
+            R = self.db_session.query(self.model).filter('"%s"=:pk_val' % (pk_name)).params(pk_val=pk_val).one()
 
         return R
 
@@ -260,7 +251,6 @@ class CRUDController(object):
         """
 
         p = int(self.request.params.get('p', '1'))
-        page_size = int(self.request.params.get('page_size', '25'))
 
         start_idx = self.list_recs_per_page * (p - 1)
 
@@ -292,12 +282,14 @@ class CRUDController(object):
         # determine primary key columns
         primary_key_columns = self.model.__table__.primary_key.columns.keys()
 
-        ret_dict = {'base_template': self.base_template, 'friendly_name': self.friendly_name,
-                'columns': columns, 'primary_key_columns': primary_key_columns,
-                'records': records, 'pages': pages, 'current_page': p,
-                'total_records': total_recs, 'records_per_page': self.list_recs_per_page,
-                'list_field_args': self.list_field_args,
-                'actions': self.list_actions, 'per_record_actions': self.list_per_record_actions}
+        ret_dict = {
+            'base_template': self.base_template, 'friendly_name': self.friendly_name,
+            'columns': columns, 'primary_key_columns': primary_key_columns,
+            'records': records, 'pages': pages, 'current_page': p,
+            'total_records': total_recs, 'records_per_page': self.list_recs_per_page,
+            'list_field_args': self.list_field_args,
+            'actions': self.list_actions, 'per_record_actions': self.list_per_record_actions
+        }
 
         return dict(ret_dict.items() + self.template_extra_params.items())
 
